@@ -15,9 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
- *
- * $Id: xine.h.in,v 1.168 2007/03/26 11:48:01 dgp85 Exp $
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA
  *
  * public xine-lib (libxine) interface and documentation
  *
@@ -113,8 +111,8 @@ int  xine_check_version (int major, int minor, int sub) XINE_PROTECTED;
 /* static info - which libxine release this header came from */
 #define XINE_MAJOR_VERSION 1
 #define XINE_MINOR_VERSION 1
-#define XINE_SUB_VERSION   8
-#define XINE_VERSION       "1.1.8"
+#define XINE_SUB_VERSION   10
+#define XINE_VERSION       "1.1.10"
 
 /*
  * pre-init the xine engine
@@ -1660,6 +1658,7 @@ void xine_config_reset (xine_t *self) XINE_PROTECTED;
 #define XINE_EVENT_VDR_AUDIO            332
 #define XINE_EVENT_VDR_INFO             333
 #define XINE_EVENT_VDR_CHANNELPREVIOUS  334
+#define XINE_EVENT_VDR_SUBTITLES        335
 /* some space for further keys */
 #define XINE_EVENT_VDR_SETVIDEOWINDOW   350
 #define XINE_EVENT_VDR_FRAMESIZECHANGED 351
